/*--arxstructs.ms-v2.12.20.143549---------------------------------------------\

	ARX Structs v2.12.20
		by Michael DarkAngel (mda@tbotr.net -- http://www.tbotr.net)
		
	Credits:
	
	Ubisoft:
	
		Without the Assassin's Creed series there would be no need for this set
		of scripts.
		
	Legal Stuff:
	
		1.	This is free software and is provided with no explicit or implied
			warranty.  If you use this software then you do so at your own
			risk.
			
		2.	If there is any law in your country that requires the author to
			provide any form of support or indemnity on the use of this
			software you are therefore not authorized to use said software as
			no such indemnity or support will be provided (per 1) other than at
			the author's discretion.
			
		3.	Credit has been given where code or methods have been integrated
			from other sources.
			
		4.	No code has been knowingly included from other sources where that
			code is sold for commercial purposes.
			
	Version Info:
	
		v1.06.17 --	Original release version.
		v1.12.28 --	Added scaleModel variable.
		--------------------------------------------------
		v2.01.15 --	Added model bone information.
		v2.01.17 --	Testing skin information.
		v2.01.22 --	V4 and V5 adjustments.
		v2.12.20 --	Removed bone and skin for now.
		
\----------------------------------------------------------------------------*/

/*
	Includes
*/

filein (scriptsPath + "\\arxImporter\\arxUI\\arxuigeneral.ms")

/*
	End Includes
*/

/*
	Struct Declaration
*/

--	Read Bone Information

struct arxBoneData (

	nameLength = 0,
	boneName = "",
	transMatrix = (matrix3 [0, 0, 0] [0, 0, 0] [0, 0, 0] [0, 0, 0]),
	
	fn Read filePointer = (
	
		fseek binReadFile filePointer #seek_set
		
		nameLength = ReadLong binReadFile
		boneName = ""
		
		for i = 1 to nameLength do (
		
			x = ReadByte binReadFile
			boneName += bit.intAsChar x
			
		)
		
		m11 = ReadFloat binReadFile
		m12 = ReadFloat binReadFile
		m13 = ReadFloat binReadFile
		m14 = ReadFloat binReadFile
		m21 = ReadFloat binReadFile
		m22 = ReadFloat binReadFile
		m23 = ReadFloat binReadFile
		m24 = ReadFloat binReadFile
		m31 = ReadFloat binReadFile
		m32 = ReadFloat binReadFile
		m33 = ReadFloat binReadFile
		m34 = ReadFloat binReadFile
		m41 = ReadFloat binReadFile
		m42 = ReadFloat binReadFile
		m43 = ReadFloat binReadFile
		m44 = ReadFloat binReadFile
		
		transMatrix = (matrix3 [m11, m12, m13] [m21, m22, m23] [m31, m32, m33] [m41, m42, m43])
	
	)

)

--	Read Mesh, Vertex and Face counts

struct arxModelData (

	modelScale = 0,
	meshCount = 0,
	vertIndices = #(),
	faceIndices = #(),
	boneCount = 0,
	skinCount = 0,
	
	fn Read filePointer = (
	
		fseek binReadFile filePointer #seek_set
		
		case arxVersion of (
		
			"V2": (
			
				modelScale = 1
			
			)
			
			default: (
			
				modelScale = ReadFloat binReadFile
			
			)
			
		)
		
		meshCount = ReadLong binReadFile
		
		for i = 1 to meshCount do (
		
			vertIndices[i] = ReadLong binReadFile
			faceIndices[i] = ReadLong binReadFile
			
		)
		
		--	Removed
		/*
		if arxVersion == "V5" then (
		
			boneCount = ReadLong binReadFile
			skinCount = ReadLong binReadFile
		
		)
		*/
		
	)
	
)

--	Read Mesh and Material information

struct arxMeshData (

	arxBones = #(),
	arxWeights = #(),
	arxVert = #(),
	arxTvert = #(),
	arxFace = #(),
	faceCount = 0,
	vertCount = 0,
	matNameLength = 0,
	matName = "",
	diffuseNameLength = 0,
	diffuseName = "",
	normalNameLength = 0,
	normalName = "",
	specularNameLength = 0,
	specularName = "",

	fn Read filePointer vertCount faceCount = (
	
		fseek binReadFile filePointer #seek_set
		
		arxImportUI.lblProgress.text = "Reading Verts"
		arxImportUI.pgbProgress.value = 0
		
		for i = 1 to vertCount do (
		
			arxImportUI.pgbProgress.value = 100.0 * i / vertCount
		
			arxVert[i] = readArxVert()
			
		)
		
		--	Removed
		/*
		if arxVersion == "V5" then (
		
			arxImportUI.lblProgress.text = "Reading Bones and Weights"
			arxImportUI.pgbProgress.value = 0
			
			for i = 1 to vertCount do (
			
				arxBones[i] = readArxBones()
				arxWeights[i] = readArxWeights()
				
				arxImportUI.pgbProgress.value = 100.0 * i / vertCount
				
			)
			
		)
		*/
		
		arxImportUI.lblProgress.text = "Reading T-Verts"
		arxImportUI.pgbProgress.value = 0
		
		for i = 1 to vertCount do (
		
			arxImportUI.pgbProgress.value = 100.0 * i / vertCount
		
			arxTvert[i] = readArxTvert()
			
		)
		
		arxImportUI.lblProgress.text = "Reading Faces"
		arxImportUI.pgbProgress.value = 0
		
		for i = 1 to faceCount do (
		
			arxImportUI.pgbProgress.value = 100.0 * i / faceCount
		
			arxFace[i] = readArxFace()
			
		)
		
		matNameLength = ReadLong binReadFile
		
		for i = 1 to matNameLength do (
		
			x = ReadByte binReadFile
			matName += bit.intAsChar x
			
		)
		
		if (matName != "NULL") then (
		
			diffuseNameLength = ReadLong binReadFile
			
			if DEBUG then (
			
				format "Diffuse Name Length = %\n" diffuseNameLength
				
			)

			for i = 1 to diffuseNameLength do (

				x = ReadByte binReadFile
				diffuseName += bit.intAsChar x

			)
			
			if DEBUG then (
			
				format "Diffuse Name = %\n" diffuseName
				
			)
			
			normalNameLength = ReadLong binReadFile
			
			if DEBUG then (
			
				format "Normal Name Length = %\n" normalNameLength
				
			)
			
			for i = 1 to normalNameLength do (
			
				x = ReadByte binReadFile
				normalName += bit.intAsChar x
				
			)
			
			if DEBUG then (
			
				format "Normal Name = %\n" normalName
				
			)
			
			specularNameLength = ReadLong binReadFile
			
			if DEBUG then (
			
				format "Specular Name Length = %\n" specularNameLength
				
			)
			
			for i = 1 to specularNameLength do (
			
				x = ReadByte binReadFile
				specularName += bit.intAsChar x
			
			)
			
			if DEBUG then (
			
				format "Specular Name = %\n" specularName
				
			)
		
		)
		
	)
	
)

--	Read Skin Information

struct arxSkinData (

	arxBoneCount = 0,
	arxBones = #(),
	
	fn Read filePointer = (
	
		arxBoneCount = ReadByte binReadFile
		
		for i = 1 to arxBoneCount do (
		
			arxBones[i] = ReadByte binReadFile
		
		)
		
	)

)

/*
	End Structs
*/
